summaryrefslogtreecommitdiff
path: root/libopie2/opiepim/backend/ocontactaccessbackend_sql.h
Side-by-side diff
Diffstat (limited to 'libopie2/opiepim/backend/ocontactaccessbackend_sql.h') (more/less context) (ignore whitespace changes)
-rw-r--r--libopie2/opiepim/backend/ocontactaccessbackend_sql.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/libopie2/opiepim/backend/ocontactaccessbackend_sql.h b/libopie2/opiepim/backend/ocontactaccessbackend_sql.h
index 55b95fd..58ae2ae 100644
--- a/libopie2/opiepim/backend/ocontactaccessbackend_sql.h
+++ b/libopie2/opiepim/backend/ocontactaccessbackend_sql.h
@@ -32,4 +32,4 @@
-#ifndef _OContactAccessBackend_SQL_
-#define _OContactAccessBackend_SQL_
+#ifndef _OPimContactAccessBackend_SQL_
+#define _OPimContactAccessBackend_SQL_
@@ -51,10 +51,10 @@ namespace Opie {
* This class is the SQL implementation of a Contact backend
* it does implement everything available for OContact.
* @see OPimAccessBackend for more information of available methods
*/
-class OContactAccessBackend_SQL : public OContactAccessBackend {
+class OPimContactAccessBackend_SQL : public OPimContactAccessBackend {
public:
- OContactAccessBackend_SQL ( const QString& appname, const QString& filename = QString::null );
+ OPimContactAccessBackend_SQL ( const QString& appname, const QString& filename = QString::null );
- ~OContactAccessBackend_SQL ();
+ ~OPimContactAccessBackend_SQL ();
@@ -70,7 +70,7 @@ class OContactAccessBackend_SQL : public OContactAccessBackend {
- OContact find ( int uid ) const;
+ OPimContact find ( int uid ) const;
// FIXME: Add lookahead-cache support !
- //OContact find(int uid, const QArray<int>&, uint cur, Frontend::CacheDirection )const;
+ //OPimContact find(int uid, const QArray<int>&, uint cur, Frontend::CacheDirection )const;
- QArray<int> queryByExample ( const OContact &query, int settings,
+ QArray<int> queryByExample ( const OPimContact &query, int settings,
const QDateTime& d );
@@ -85,5 +85,5 @@ class OContactAccessBackend_SQL : public OContactAccessBackend {
QArray<int> sorted( bool asc, int , int , int );
- bool add ( const OContact &newcontact );
+ bool add ( const OPimContact &newcontact );
- bool replace ( const OContact &contact );
+ bool replace ( const OPimContact &contact );
@@ -51,10 +51,10 @@ namespace Opie {
* This class is the SQL implementation of a Contact backend
- * it does implement everything available for OContact.
+ * it does implement everything available for OPimContact.
* @see OPimAccessBackend for more information of available methods
*/